**Example 1: DescribeRiskAssessment**



Input: 

```
tccli rce DescribeRiskAssessment --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "a6227506-5f00-43cf-9a4c-66fe931cefc9"
    }
}
```

